MODULE solvers

! This module contains simultaneous equation solvers.

INTERFACE 

   MODULE SUBROUTINE simul ( a, b, ndim, n, error )
   !
   !  Purpose:
   !    Subroutine to solve a set of n linear equations in n 
   !    unknowns using Gaussian elimination and the maximum 
   !    pivot technique.
   !
   !  Record of revisions:
   !      Date       Programmer          Description of change
   !      ====       ==========          =====================
   !    12/23/15    S. J. Chapman        Original code
   !
   IMPLICIT NONE

   ! Data dictionary: declare calling parameter types & definitions
   INTEGER, INTENT(IN) :: ndim          ! Dimension of arrays a and b
   REAL, INTENT(INOUT), DIMENSION(ndim,ndim) :: a 
                    ! Array of coefficients (n x n).
                    ! This array is of size ndim x 
                    ! ndim, but only n x n of the 
                    ! coefficients are being used.
                    ! The declared dimension ndim 
                    ! must be passed to the sub, or
                    ! it won't be able to interpret
                    ! subscripts correctly.  (This
                    ! array is destroyed during
                    ! processing.)
   REAL, INTENT(INOUT), DIMENSION(ndim) :: b 
                    ! Input: Right-hand side of eqns.
                    ! Output: Solution vector.
   INTEGER, INTENT(IN) :: n             ! Number of equations to solve.
   INTEGER, INTENT(OUT) :: error        ! Error flag:
                    !   0 -- No error
                    !   1 -- Singular equations
   END SUBROUTINE simul
   
END INTERFACE

END MODULE solvers
